@@ -4,7 +4,7 @@ use teloxide::prelude2::*;
 
 #[tokio::main]
 async fn main() {
-    teloxide::enable_logging!();
+    pretty_env_logger::init();
     log::info!("Starting dices_bot...");
 
     let bot = Bot::from_env().auto_send();
